@@ -26,6 +26,7 @@ class RNVideoTrimmer: NSObject {
         var sTime = options.object(forKey: "startTime") as? Float
         var eTime = options.object(forKey: "endTime") as? Float
         let quality = ((options.object(forKey: "quality") as? String) != nil) ? options.object(forKey: "quality") as! String : ""
+        let saveToCameraRoll = options.object(forKey: "saveToCameraRoll") as? Bool ?? false
 
         let manager = FileManager.default
         guard let documentDirectory = try? manager.url(for: .documentDirectory, in: .userDomainMask, appropriateFor: nil, create: true)
@@ -77,8 +78,10 @@ class RNVideoTrimmer: NSObject {
             switch exportSession.status {
             case .completed:
                 callback( [NSNull(), outputURL.absoluteString] )
-                UISaveVideoAtPathToSavedPhotosAlbum(outputURL.relativePath, self, nil, nil)
-                
+                if saveToCameraRoll {
+                    UISaveVideoAtPathToSavedPhotosAlbum(outputURL.relativePath, self, nil, nil)
+                }
+
             case .failed:
                 callback( ["Failed: \(exportSession.error?.localizedDescription)", NSNull()] )
                 
@@ -90,6 +93,87 @@ class RNVideoTrimmer: NSObject {
         }
     }
 
+    @objc func compress(_ source: String, options: NSDictionary, callback: @escaping RCTResponseSenderBlock) {
+        
+        var width = options.object(forKey: "width") as? Float
+        var height = options.object(forKey: "height") as? Float
+        let bitrateMultiplier = options.object(forKey: "bitrateMultiplier") as? Float ?? 1
+        let saveToCameraRoll = options.object(forKey: "saveToCameraRoll") as? Bool ?? false
+        
+        let manager = FileManager.default
+        guard let documentDirectory = try? manager.url(for: .documentDirectory, in: .userDomainMask, appropriateFor: nil, create: true)
+            else {
+                callback(["Error creating FileManager", NSNull()])
+                return
+        }
+        
+        let sourceURL = getSourceURL(source: source)
+        let asset = AVAsset(url: sourceURL as URL)
+        
+        guard let videoTrack = asset.tracks(withMediaType: AVMediaTypeVideo).first else  {
+            callback(["Error getting track info", NSNull()])
+            return
+        }
+        
+        let naturalSize = videoTrack.naturalSize.applying(videoTrack.preferredTransform)
+        let bps = videoTrack.estimatedDataRate
+        width = width ?? Float(abs(naturalSize.width))
+        height = height ?? Float(abs(naturalSize.height))
+        
+        var outputURL = documentDirectory.appendingPathComponent("output")
+        do {
+            try manager.createDirectory(at: outputURL, withIntermediateDirectories: true, attributes: nil)
+            let name = randomString()
+            outputURL = outputURL.appendingPathComponent("\(name)-compressed.mp4")
+        } catch {
+            callback([error.localizedDescription, NSNull()])
+            print(error)
+        }
+        
+        //Remove existing file
+        _ = try? manager.removeItem(at: outputURL)
+        
+        let compressionEncoder = SDAVAssetExportSession(asset: asset)
+        if compressionEncoder == nil {
+            callback(["Error creating AVAssetExportSession", NSNull()])
+            return
+        }
+        compressionEncoder!.outputFileType = AVFileTypeMPEG4
+        compressionEncoder!.outputURL = NSURL.fileURL(withPath: outputURL.path)
+        compressionEncoder!.shouldOptimizeForNetworkUse = true
+        compressionEncoder?.videoSettings = [
+            AVVideoCodecKey: AVVideoCodecH264,
+            AVVideoWidthKey: NSNumber.init(value: width!),
+            AVVideoHeightKey: NSNumber.init(value: height!),
+            AVVideoCompressionPropertiesKey: [
+                AVVideoAverageBitRateKey: NSNumber.init(value: bps / bitrateMultiplier),
+                AVVideoProfileLevelKey: AVVideoProfileLevelH264High40
+            ]
+        ]
+        compressionEncoder?.audioSettings = [
+            AVFormatIDKey: kAudioFormatMPEG4AAC,
+            AVNumberOfChannelsKey: 2,
+            AVSampleRateKey: 44100,
+            AVEncoderBitRateKey: 128000
+        ]
+        compressionEncoder!.exportAsynchronously(completionHandler: {
+            switch compressionEncoder!.status {
+            case .completed:
+                callback( [NSNull(), outputURL.absoluteString] )
+                if saveToCameraRoll {
+                    UISaveVideoAtPathToSavedPhotosAlbum(outputURL.relativePath, self, nil, nil)
+                }
+            case .failed:
+                callback( ["Failed: \(compressionEncoder!.error?.localizedDescription)", NSNull()] )
+                
+            case .cancelled:
+                callback( ["Cancelled: \(compressionEncoder!.error?.localizedDescription)", NSNull()] )
+                
+            default: break
+            }
+        })
+    }
+
     @objc func getAssetInfo(_ source: String, callback: RCTResponseSenderBlock) {
         let sourceURL = getSourceURL(source: source)
         let asset = AVAsset(url: sourceURL)
@@ -98,7 +182,12 @@ class RNVideoTrimmer: NSObject {
         ]
         if let track = asset.tracks(withMediaType: AVMediaTypeVideo).first {
             let naturalSize = track.naturalSize
-            let size = ["width": naturalSize.width, "height": naturalSize.height]
+            let t = track.preferredTransform
+            let isPortrait = t.a == 0 && abs(t.b) == 1 && t.d == 0
+            let size = [
+              "width": isPortrait ? naturalSize.height : naturalSize.width,
+              "height": isPortrait ? naturalSize.width : naturalSize.height
+            ]
             assetInfo["size"] = size
         }
         callback( [NSNull(), assetInfo] )
