@@ -49,6 +49,7 @@ export class VideoPlayer extends Component {
 		super(...args);
 		this.state = {};
 		this.trim = this.trim.bind(this);
+		this.compress = this.compress.bind(this);
 		this.getPreviewForSecond = this.getPreviewForSecond.bind(this);
 		this.getVideoInfo = this.getVideoInfo.bind(this);
 		this._onChange = this._onChange.bind(this);
@@ -111,6 +112,39 @@ export class VideoPlayer extends Component {
 		});
 	}
 
+	compress(source, _options = {}) {
+		const options = { ..._options };
+		// const options = {
+		// 	height: 1080, // output video's height
+		// 	width: 720, // output video's width
+		// 	bitrateMultiplier: 10 // divide video's bitrate to this value
+		// };
+		if (options.hasOwnProperty('bitrateMultiplier') && options.bitrateMultiplier <= 0) {
+			options.bitrateMultiplier = 1;
+			// eslint-disable-next-line no-console
+			console.warn('bitrateMultiplier cannot be less than zero');
+		}
+		if (options.hasOwnProperty('height') && options.height <= 0) {
+			delete options.height;
+			// eslint-disable-next-line no-console
+			console.warn('height cannot be less than zero');
+		}
+		if (options.hasOwnProperty('width') && options.width <= 0) {
+			delete options.width;
+			// eslint-disable-next-line no-console
+			console.warn('width cannot be less than zero');
+		}
+		const actualSource = getActualSource(source);
+		return new Promise((resolve, reject) => {
+			RNVideoTrimmer.compress(actualSource, options, (err, output) => {
+				if (err) {
+					return reject(err);
+				}
+				return resolve(output);
+			});
+		});
+	}
+
 	render() {
 		const {
 			source,
